@@ -9,11 +9,13 @@ __all__ = ['activation',
            'gradient',
            'optimizer',
            'load',
+           'save',
            'CNN',
            'RNN',
+           'GUI',
            'datasets']
 
 from phidnet import *
-from phidnet.matrix import matrix
-from phidnet.matrix.matrix import array
-from phidnet.matrix.matrix_class import Matrix
\ No newline at end of file
+from phidnet.matrix import matrix   # matrix.py 
+from phidnet.matrix.matrix import array   # array()
+from phidnet.matrix.matrix_class import Matrix
